/// <reference path="../Scripts/typings/angularjs/angular.d.ts" />
/// <reference path="../Scripts/typings/jquery/jquery.d.ts" />
declare module AmpCoreApi {
    enum AADAppName {
        api = 0,
        opstool = 1,
        monitoring = 2,
        rdpclient = 3,
        ampdash = 4,
        pstool = 5,
    }
    interface IAADApp extends IEntity {
        name: AADAppName;
        clientId: string;
        appIdUri: string;
        dnsName: string;
        trafficManagerUrl: string;
    }
    module Services {
        class AmpAADAppService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listAADApps(): ng.IPromise<Array<IAADApp>>;
            getAADApp(id: string): ng.IPromise<IAADApp>;
            createAADApp(aadApp: IAADApp): ng.IPromise<IAADApp>;
            deleteAADApp(id: string): ng.IPromise<void>;
            getAADAppByName(name: string): ng.IPromise<IAADApp>;
        }
    }
}
declare module AmpCoreApi {
    interface IAADWebsite extends IEntity {
        name: string;
        azureRegion: string;
        aadAppId: string;
        siteLinkUse: boolean;
    }
    module Services {
        class AmpAADWebsiteService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listAADWebsites(): ng.IPromise<Array<IAADWebsite>>;
            getAADWebsite(id: string): ng.IPromise<IAADWebsite>;
            createAADWebsite(aadWebsite: IAADWebsite): ng.IPromise<IAADWebsite>;
            deleteAADWebsite(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface IAccount extends IEntity {
        name: string;
        shortName: string;
        externalIdentity: string;
    }
    module Services {
        class AmpAccountService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listAccounts(): ng.IPromise<Array<IAccount>>;
            getAccount(id: string): ng.IPromise<IAccount>;
            createAccount(account: IAccount): ng.IPromise<IAccount>;
            updateAccount(account: IAccount): ng.IPromise<void>;
            deleteAccount(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface IAzureLocation {
        name: string;
        displayName: string;
    }
    interface IWebSiteInfo {
        name: string;
        location: IAzureLocation;
    }
    module Services {
        class AmpAzureService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listAzureLocations(): ng.IPromise<Array<IAzureLocation>>;
            getAzureWebsiteInfo(): ng.IPromise<IWebSiteInfo>;
        }
    }
}
declare module AmpCoreApi {
    interface IBundle extends ITrackedEntityBase {
        name?: string;
        version?: string;
        description?: string;
    }
    interface IBundlePrefetch {
        bundle?: IBundle;
        dependencies?: string[];
        probes?: IProbe[];
        triggers?: ITrigger[];
        percolators?: IPercolator[];
    }
    interface IIssuer extends ITrackedEntityBase {
        bundleId?: string;
        name?: string;
        description?: string;
        severity?: number;
        query?: string;
        issueType?: string;
        resource?: string;
        response?: string;
        responder?: string;
        type?: string;
        visualization?: string;
        rollup?: boolean;
        implementationNotes?: string;
    }
    interface ISiteIssuer {
        name?: string;
        description?: string;
        severity?: number;
        query?: string;
        issueType?: string;
        resource?: string;
        response?: string;
        responder?: string;
        lastModifiedDate?: string;
        bundle?: string;
        type?: string;
        visualization?: string;
    }
    module Services {
        class AmpBundleService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listBundles(): ng.IPromise<IBundle[]>;
            listBundlesPrefetch(): ng.IPromise<IBundlePrefetch[]>;
            getBundle(id: string): ng.IPromise<IBundle>;
            createBundle(bundle: IBundle): ng.IPromise<IBundle>;
            updateBundle(bundle: IBundle, comment?: string): ng.IPromise<void>;
            deleteBundle(id: string): ng.IPromise<void>;
            getBundlePackageUrl(id: string): ng.IPromise<any>;
            getBundlePrefetch(id: string): ng.IPromise<IBundlePrefetch>;
            upsertBundleDependencies(id: string, dependencies: string[]): ng.IPromise<void>;
        }
    }
}
interface Window {
    ampConfig: {
        adalClientId: string;
        adalEndpoints: {
            [indexer: string]: string;
        };
        appInsightsKey: string;
        coreApiUri: string;
        cacheLocation: string;
        debugEnabled: boolean;
        debugVerbose: boolean;
        clientVersion: string;
        enableDevFeatures?: boolean;
    };
}
declare module AmpCoreApi {
    interface IEntity {
        id?: string;
    }
    interface ITrackedEntityBase extends IEntity {
        createdDate?: string;
        lastModifiedDate?: string;
        rowVersion?: string;
    }
}
declare module AmpCoreApi {
    interface ICoreSecurityGroup extends IEntity {
        name: string;
        externalIdentity: string;
        tenantId: string;
        canCreate?: boolean;
        canDelete?: boolean;
        editSiteAccess?: boolean;
        admin?: boolean;
        opsAdmin?: boolean;
    }
    module Services {
        class AmpCoreSecurityGroupService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listCoreSecurityGroups(): ng.IPromise<Array<ICoreSecurityGroup>>;
            getCoreSecurityGroup(id: string): ng.IPromise<ICoreSecurityGroup>;
            createCoreSecurityGroup(coreSg: ICoreSecurityGroup): ng.IPromise<ICoreSecurityGroup>;
            updateCoreSecurityGroup(coreSg: ICoreSecurityGroup): ng.IPromise<void>;
            deleteCoreSecurityGroup(id: string): ng.IPromise<void>;
            listCoreSecurityGroupsByTenant(tenantId: string): ng.IPromise<Array<ICoreSecurityGroup>>;
        }
    }
}
declare module AmpCoreApi {
    interface ICredential extends IEntity {
        name: string;
        secretId: string;
        description: string;
        tags: Array<string>;
        targets: Array<string>;
        targetTypes: Array<string>;
        tenant: string;
        roles: Array<string>;
    }
    module Services {
        class AmpCredentialService {
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            list(siteId: string): ng.IPromise<Array<ICredential>>;
            create(siteId: string, c: ICredential): ng.IPromise<ICredential>;
            update(siteId: string, c: ICredential): ng.IPromise<void>;
            remove(siteId: string, id: string): ng.IPromise<void>;
            get(siteId: string, id: string): ng.IPromise<ICredential>;
            sync(siteId: string): ng.IPromise<boolean>;
            listAll(siteId: string): ng.IPromise<Array<ICredential>>;
            private routeToId(id);
        }
    }
}
declare module AmpCoreApi {
    enum UserRoles {
        CoreCanCreate = 0,
        CoreCanDelete = 1,
        CoreAdmin = 2,
        OpsAdmin = 3,
        EditSiteAccess = 4,
    }
    interface IUser extends IEntity {
        displayName: string;
        thumbnailPhoto: string;
        userPrincipalName: string;
        roles: Array<string>;
    }
    interface IDirectory {
        identity: string;
        name: string;
    }
    interface IDirectorySecurityGroup {
        tenantIdentity: string;
        identity: string;
        displayName: string;
    }
    module Services {
        class AmpDirectoryService {
            private _httpService;
            private _routePrefix;
            private _qService;
            static IID: string;
            static $inject: Array<string>;
            constructor($qService: ng.IQService, httpService: AmpHttpService);
            me(): ng.IPromise<IUser>;
            getDirectory(): ng.IPromise<IDirectory>;
            getSecurityGroups(displayNameFilter?: string): ng.IPromise<Array<IDirectorySecurityGroup>>;
            getSecurityGroup(id: string): ng.IPromise<IDirectorySecurityGroup>;
        }
    }
}
declare module AmpCoreApi.Services {
    class AmpHttpService {
        private _httpService;
        private _qService;
        private _uriBase;
        static IID: string;
        static $inject: Array<string>;
        constructor($http: ng.IHttpService, $q: ng.IQService);
        setBaseAddress(uri: string): void;
        getBaseAddress(): string;
        listResources<T>(uri: string): ng.IPromise<Array<T>>;
        getResource<T>(uri: string): ng.IPromise<T>;
        createResource<T>(uri: string, data: T): ng.IPromise<T>;
        updateResource<T>(uri: string, data: T): ng.IPromise<void>;
        deleteResource(uri: string): ng.IPromise<void>;
        postResource<T>(uri: string, data?: T): ng.IPromise<T>;
        postResourceDifferentOutput<T, TV>(uri: string, data?: T): ng.IPromise<TV>;
        putResource<T>(uri: string, data: T): ng.IPromise<void>;
        putResourceWithResponse<T>(uri: string, data: T): ng.IPromise<any>;
        linkResources(uri: string): ng.IPromise<void>;
        unlinkResources(uri: string): ng.IPromise<void>;
        static makeQueryString(prefix: string, vars: {
            [key: string]: any;
        }): string;
    }
}
declare module AmpCoreApi {
    interface IInsightsConfig {
        instrumentationKey: string;
        endpointUrl?: string;
        emitLineDelimitedJson?: boolean;
        accountId?: string;
        appUserId?: string;
        sessionRenewalMs?: number;
        sessionExpirationMs?: number;
        maxBatchSizeInBytes?: number;
        maxBatchInterval?: number;
        enableDebug?: boolean;
        disableExceptionTracking?: boolean;
        disableTelemetry?: boolean;
        verboseLogging?: boolean;
        diagnosticLogInterval?: number;
        samplingPercentage?: number;
        autoTrackPageVisitTime?: boolean;
        disableAjaxTracking?: boolean;
        overridePageViewDuration?: boolean;
        maxAjaxCallsPerView?: number;
        disableDataLossAnalysis?: boolean;
        disableCorrelationHeaders?: boolean;
    }
    module Services {
        class AmpInsightsService {
            private appInsights;
            static IID: string;
            constructor();
            configure(config: IInsightsConfig): void;
            /**
            * Logs that a page or similar container was displayed to the user.
            * @param {string} name The name used to identify the page in the portal. Defaults to the document title.
            * @param {string} url A relative or absolute URL that identifies the page or similar item. Defaults to the window location.
            * @param {{[string]:string}} properties Map of string to string: Additional data used to filter pages in the portal. Defaults to empty.
            * @param {{[string]:number}} measurements Map of string to number: Metrics associated with this page, displayed in Metrics Explorer on the portal. Defaults to empty.
            */
            trackPageView(name?: string, url?: string, properties?: {}, measurements?: {}): void;
            /**
            * Logs that a page or similar container was displayed to the user.
            * @param {string} name A string that identifies the metric. In the portal, you can select metrics for display by name.
            * @param {number} average Either a single measurement, or the average of several measurements. Should be >=0 to be correctly displayed.
            * @param {number} sampleCount Count of measurements represented by the average. Defaults to 1. Should be >=1.
            * @param {number} min The smallest measurement in the sample. Defaults to the average. Should be >= 0.
            * @param {number} max The largest measurement in the sample. Defaults to the average. Should be >= 0.
            */
            trackEvent(name: string, properties?: {}, measurements?: {}): void;
            /**
            * Logs that a page or similar container was displayed to the user.
            * @param {string} name A string that identifies the metric. In the portal, you can select metrics for display by name.
            * @param {number} average Either a single measurement, or the average of several measurements. Should be >=0 to be correctly displayed.
            * @param {number} sampleCount Count of measurements represented by the average. Defaults to 1. Should be >=1.
            * @param {number} min The smallest measurement in the sample. Defaults to the average. Should be >= 0.
            * @param {number} max The largest measurement in the sample. Defaults to the average. Should be >= 0.
            */
            trackMetric(name: string, average: number, sampleCount?: number, min?: number, max?: number): void;
            /**
            * Logs that a page or similar container was displayed to the user.
            * @param {Error} exception An Error from a catch clause.
            * @param {string} handledAt Defaults to "unhandled".
            * @param {{[string]:string}} properties Map of string to string: Additional data used to filter pages in the portal. Defaults to empty.
            * @param {{[string]:number}} measurements Map of string to number: Metrics associated with this page, displayed in Metrics Explorer on the portal. Defaults to empty.
            */
            trackException(exception: Error, handledAt?: string, properties?: {}, measurements?: {}): void;
            /**
            * Log a diagnostic event such as entering or leaving a method.
            * @param {string} message Diagnostic data. Can be much longer than a name.
            * @param {{[string]:string}} properties Map of string to string: Additional data used to filter pages in the portal. Defaults to empty.
            * @param {{[string]:number}} measurements Map of string to number: Metrics associated with this page, displayed in Metrics Explorer on the portal. Defaults to empty.
            */
            trackTrace(message: string, properties?: {}, measurements?: {}): void;
            /**
            * Immediately send all queued telemetry. Synchronous.
            */
            flush(): void;
            /**
            * Set the authenticated user id and the account id in this session. Use this when you have identified a specific signed-in user. Parameters must not contain spaces or ,;=|
            * @param {string} authenticatedUserId An id that uniquely identifies a user of your app. No spaces, comma, semicolon, equals or vertical bar.
            * @param {string} accountId An optional account id, if your app groups users into accounts. No spaces, comma, semicolon, equals or vertical bar.
            */
            setAuthenticatedUserContext(authenticatedUserId: string, accountId?: string): void;
            /**
            * Clears the authenticated user id and the account id from the user context, and clears the associated cookie.
            */
            clearAuthenticatedUserContext(): void;
        }
    }
}
declare module AmpCoreApi {
    class AmpKibanaConfigType {
        static dashboard: string;
        static search: string;
        static visualization: string;
    }
    interface IKibanaConfig extends ITrackedEntityBase {
        bundleId?: string;
        elasticIdentity?: string;
        sourceJson?: string;
    }
    module Services {
        class AmpKibanaConfigService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listKibanaConfigs(): ng.IPromise<Array<IKibanaConfig>>;
            getKibanaConfig(id: string): ng.IPromise<IKibanaConfig>;
            createKibanaConfig(kibanaConfig: IKibanaConfig): ng.IPromise<IKibanaConfig>;
            updateKibanaConfig(kibanaConfig: IKibanaConfig): ng.IPromise<void>;
            deleteKibanaConfig(id: string): ng.IPromise<void>;
            getKibanaConfigByElasticIdentity(elasticIdentity: string): ng.IPromise<IKibanaConfig>;
            listKibanaConfigByBundle(bundleId: string): ng.IPromise<Array<IKibanaConfig>>;
        }
    }
}
declare module AmpCoreApi {
    interface IPercolator extends IIssuer {
        matchAll?: boolean;
    }
    module Services {
        class AmpPercolatorService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listPercolators(): ng.IPromise<IPercolator[]>;
            getPercolator(id: string): ng.IPromise<IPercolator>;
            createPercolator(percolator: IPercolator): ng.IPromise<IPercolator>;
            updatePercolator(percolator: IPercolator, comment?: string): ng.IPromise<void>;
            deletePercolator(id: string): ng.IPromise<void>;
            listPercolatorsByBundle(bundleId: string): ng.IPromise<IPercolator[]>;
        }
    }
}
declare module AmpCoreApi {
    interface IPingTelemetry extends IEntity {
        rdpTelemetryId: string;
        batchNumber: number;
        numberOfPings: number;
        averageRoundtrip: number;
        maxRoundtrip: number;
        minRoundtrip: number;
        data: string;
    }
    module Services {
        class AmpPingTelemetryService {
            private _httpService;
            private _qService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService, $q: ng.IQService);
            listPingTelemetries(rdpTelemetryId: string): ng.IPromise<IPingTelemetry[]>;
            createPingTelemetry(ping: IPingTelemetry): ng.IPromise<IPingTelemetry>;
        }
    }
}
declare module AmpCoreApi {
    enum ParameterType {
        String = 0,
        Integer = 1,
        Float = 2,
        Boolean = 3,
        DateTime = 4,
        Guid = 5,
        TimeSpan = 6,
        StringArray = 7,
    }
    enum PropertyType {
        Unknown = 0,
        String = 1,
        Number = 2,
        Date = 3,
        Boolean = 4,
        Binary = 5,
        Float = 6,
        Double = 7,
        Byte = 8,
        Short = 9,
        Integer = 10,
        Long = 11,
    }
    interface IProbe extends ITrackedEntityBase {
        bundleId?: string;
        name?: string;
        description?: string;
        provider?: string;
        crontab?: string;
        parameters?: {
            [indexer: string]: string;
        };
        properties?: {
            [indexer: string]: IPropertyMetadata;
        };
        discard?: boolean;
    }
    interface IParameterMetadata {
        defaultValue: any;
        description: string;
        required: boolean;
        multiline: boolean;
        type: ParameterType;
        values?: Array<string>;
    }
    interface IPropertyMetadata {
        analyze?: boolean;
        description?: string;
        type?: PropertyType;
        array?: boolean;
    }
    interface IProviderMetadata {
        name?: string;
        description?: string;
        active?: boolean;
        remote?: boolean;
        parameters?: {
            [indexer: string]: IParameterMetadata;
        };
    }
    interface IResult {
        type?: string;
        bundle?: string;
        provider?: string;
        targetId?: string;
        targetName?: string;
        targetExternalIdentity?: string;
        timestamp?: string;
        properties?: {
            [indexer: string]: string;
        };
        exception?: string;
        targetCustomerIdentity?: string;
    }
    module Services {
        class AmpProbeService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listProbes(): ng.IPromise<Array<IProbe>>;
            getProbe(id: string): ng.IPromise<IProbe>;
            createProbe(probe: IProbe): ng.IPromise<IProbe>;
            updateProbe(probe: IProbe, comment?: string): ng.IPromise<void>;
            deleteProbe(id: string): ng.IPromise<void>;
            listProbesByBundle(bundleId: string): ng.IPromise<Array<IProbe>>;
            getProbeByName(probeName: string): ng.IPromise<IProbe>;
        }
    }
}
declare module AmpCoreApi {
    interface IRdpLog extends IEntity {
        userIdentity: string;
        startTimeUtc: Date;
        endTimeUtc?: Date;
        accountExternalIdentity: string;
        accountIdentity: string;
        accountName: string;
        siteExternalIdentity: string;
        siteIdentity: string;
        siteName: string;
        hopSiteIdentity: string;
        hopSiteName: string;
        targetIdentity: string;
        targetName: string;
        connectionIdentity: string;
        bytesSent: number;
        bytesReceived: number;
    }
    module Services {
        class AmpRdpLogService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            getRdpLog(id: string): ng.IPromise<IRdpLog>;
            listRdpLogs(from?: string, to?: string, user?: string, accountId?: string, siteId?: string, targetId?: string): ng.IPromise<IRdpLog[]>;
        }
    }
}
declare module AmpCoreApi {
    interface IRdpSession extends IEntity {
        connectionIdentity: string;
        startTime: string;
        userIdentity: string;
        credentialIdentity: string;
        targetId: string;
    }
    module Services {
        class AmpRdpSessionService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listRdpSessions(targetId: string): ng.IPromise<Array<IRdpSession>>;
            listRdpSessionsBySite(siteId: string): ng.IPromise<Array<IRdpSession>>;
            deleteRdpSession(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface IRdpTelemetry extends IEntity {
        userId: string;
        accountId: string;
        siteId: string;
        hopSiteId?: string;
        targetId: string;
        hostServerName?: string;
        connectTime: Date;
        disconnectTime?: Date;
        connectionMethod?: AmpCoreApi.RdpConnectors;
        rdpLogId?: string;
        coreClockOffset?: number;
        siteClockOffset?: number;
        userLatitude?: number;
        userLongitude?: number;
        websiteRegion: string;
        connectionRegion: string;
    }
    module Services {
        class AmpRdpTelemetryService {
            private _httpService;
            private _qService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService, $q: ng.IQService);
            getRdpTelemetry(id: string): ng.IPromise<IRdpTelemetry>;
            getRdpTelemetryByLogId(logId: string): ng.IPromise<IRdpTelemetry>;
            listRdpTelemetries(from?: string, to?: string, user?: string, accountId?: string, siteId?: string, targetId?: string): ng.IPromise<Array<IRdpTelemetry>>;
            createRdpTelemetry(telemetry: IRdpTelemetry): ng.IPromise<IRdpTelemetry>;
            updateRdpTelemetry(telemetry: IRdpTelemetry): ng.IPromise<void>;
            endRdpTelemetry(telemetry: IRdpTelemetry): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    module Services {
        class AmpRedisCacheService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            clearCache(): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface IScriptExecutionLog extends IEntity {
        userIdentity: string;
        startTimeUtc: Date;
        endTimeUtc?: Date;
        accountId: string;
        accountName: string;
        siteId: string;
        siteName: string;
        data: string;
        remoteIpAddress: string;
        connectionId: string;
    }
    module Services {
        class AmpScriptExecutionLogService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            getScriptExecutionLog(id: string): ng.IPromise<IScriptExecutionLog>;
            listScriptExecutionLogs(from?: string, to?: string, user?: string, accountId?: string, siteId?: string): ng.IPromise<Array<IScriptExecutionLog>>;
        }
    }
}
declare module AmpCoreApi {
    interface IScriptParameter {
        name: string;
        description: string;
        type: string;
        defaultValue: any;
        mandatory: boolean;
        position?: number;
    }
    interface IScript extends IEntity {
        name: string;
        description: string;
        text: string;
        parameters?: Array<IScriptParameter>;
        categories?: Array<string>;
    }
    interface IScriptError {
        line: string;
        lineNumber: number;
        column: number;
        message: string;
    }
    interface IScriptResult {
        script: IScript;
        errors: Array<IScriptError>;
    }
    module Services {
        class AmpScriptService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            getScript(id: string): ng.IPromise<IScript>;
            createScript(script: IScript): ng.IPromise<IScript>;
            updateScript(script: IScript): ng.IPromise<void>;
            deleteScript(id: string): ng.IPromise<void>;
            listScripts(): ng.IPromise<Array<IScript>>;
            parseScript(script: IScript): ng.IPromise<IScriptResult>;
        }
    }
}
declare module AmpCoreApi {
    interface ISecurityLog extends IEntity {
        userIdentity: string;
        startTime: number;
        target: string;
        allowed: boolean;
        method: string;
        statusCode: number;
        source: string;
        remoteIpAddress: string;
        correlationIdentity: string;
        details: string;
    }
    module Services {
        class AmpSecurityLogService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            getSecurityLog(id: string): ng.IPromise<ISecurityLog>;
            listSecurityLogs(): ng.IPromise<Array<ISecurityLog>>;
        }
    }
}
declare module AmpCoreApi {
    interface IIssue {
        additionalInfo: string;
        autoFix?: boolean;
        description: string;
        consumed: boolean;
        id: string;
        probeName: string;
        resource: string;
        severity?: number;
        targetExternalIdentity: string;
        targetId: string;
        targetName: string;
        targetTenant: string;
        timestamp: Date;
        'type': string;
    }
    module Services {
        class AmpSiteIssueService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            list(siteId: string): ng.IPromise<Array<IIssue>>;
        }
    }
}
declare module AmpCoreApi {
    module Services {
        class AmpSiteKibanaConfigService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: string[];
            constructor(httpService: AmpHttpService);
            listDashboards(siteId: string): ng.IPromise<Array<string>>;
            exportDashboards(siteId: string, siteDashboardIdentities: string[]): ng.IPromise<void>;
            importDashboards(siteId: string, coreDashboardIdentities: string[]): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface ISitePercolator extends ISiteIssuer {
        matchAll?: boolean;
    }
    module Services {
        class AmpSitePercolatorService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            test(siteId: string, c: ISitePercolator): ng.IPromise<Array<IResult>>;
            render(siteId: string, c: Array<IResult>): ng.IPromise<Array<IIssue>>;
            private routeToId(id);
        }
    }
}
declare module AmpCoreApi {
    interface ISiteProbe {
        name?: string;
        description?: string;
        provider?: string;
        crontab?: string;
        parameters?: {
            [indexer: string]: string;
        };
        properties?: {
            [indexer: string]: IPropertyMetadata;
        };
        lastModifiedDate?: string;
        bundle?: string;
        discard?: boolean;
    }
}
declare module AmpCoreApi {
    interface IProviderExecuteRequest {
        target: ITarget;
        probe: ISiteProbe;
    }
    interface IProviderQueryRequest {
        target: ITarget;
        parameters: {
            [indexer: string]: string;
        };
    }
    module Services {
        class AmpSiteProviderService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($q: ng.IQService, $rsp: AmpSiteProxyService);
            list(siteId: string): ng.IPromise<Array<IProviderMetadata>>;
            query(siteId: string, provider: string, bundle: string, request: IProviderQueryRequest): ng.IPromise<ISiteProbe>;
            execute(siteId: string, request: IProviderExecuteRequest): ng.IPromise<Array<IResult>>;
            get(siteId: string, id: string): ng.IPromise<IProviderMetadata>;
            private routeToId(id);
        }
    }
}
declare module AmpCoreApi {
    module Services {
        enum ProxyHttpMethod {
            "badrequest" = 0,
            "get" = 1,
            "post" = 2,
            "put" = 3,
            "delete" = 4,
        }
        interface ISiteProxyMessage {
            method: ProxyHttpMethod;
            uri: string;
            data?: any;
        }
        class AmpSiteProxyService {
            private _httpService;
            private _q;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor($q: ng.IQService, httpService: AmpHttpService);
            listResources<T>(siteId: string, uri: string): ng.IPromise<Array<T>>;
            getResource<T>(siteId: string, uri: string): ng.IPromise<T>;
            postResources<T>(siteId: string, uri: string, data: T): ng.IPromise<T>;
            postResourceDifferentOutput<T, TV>(siteId: string, uri: string, data: T): ng.IPromise<TV>;
            postResourceNoBody(siteId: string, uri: string): ng.IPromise<void>;
            putResources<T>(siteId: string, uri: string, data: T): ng.IPromise<void>;
            deleteResource(siteId: string, uri: string): ng.IPromise<void>;
            private postSiteProxy(siteId, siteMessage);
        }
    }
}
declare module AmpCoreApi {
    module Services {
        class AmpSiteResponderService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($q: ng.IQService, $rsp: AmpSiteProxyService);
            list(siteId: string): ng.IPromise<Array<string>>;
        }
    }
}
declare module AmpCoreApi {
    interface ISiteRule extends IEntity {
        allowed?: boolean;
        admin?: boolean;
        auditRead?: boolean;
        coreSgId: string;
        siteId: string;
    }
    module Services {
        class AmpSiteRuleService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listSiteRules(): ng.IPromise<Array<ISiteRule>>;
            getSiteRule(id: string): ng.IPromise<ISiteRule>;
            createSiteRule(siteRule: ISiteRule): ng.IPromise<ISiteRule>;
            updateSiteRule(siteRule: ISiteRule): ng.IPromise<void>;
            deleteSiteRule(id: string): ng.IPromise<void>;
            listSiteRulesBySite(siteId: string): ng.IPromise<Array<ISiteRule>>;
            listSiteRulesByCoreSg(coreSgId: string): ng.IPromise<Array<ISiteRule>>;
            listSiteRulesByAccount(accountId: string): ng.IPromise<Array<ISiteRule>>;
        }
    }
}
declare module AmpCoreApi {
    interface ISiteSchedule {
        name?: string;
        bundle: string;
        targetId: string;
    }
    module Services {
        class AmpSiteScheduleService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            list(siteId: string): ng.IPromise<Array<ISiteSchedule>>;
            store(siteId: string, schedule: ISiteSchedule, id?: string): ng.IPromise<void>;
            storeMultiple(siteId: string, schedules: Array<ISiteSchedule>): ng.IPromise<void>;
            remove(siteId: string, id: string): ng.IPromise<void>;
            removeMultiple(siteId: string, ids: Array<string>): ng.IPromise<void>;
            get(siteId: string, id: string): ng.IPromise<ISiteSchedule>;
            getByTarget(siteId: string, targetId: string): ng.IPromise<Array<ISiteSchedule>>;
            private routeToId(id);
        }
    }
}
declare module AmpCoreApi {
    enum RdpConnectors {
        hcm = 0,
        webService = 1,
    }
    interface ISite extends IEntity {
        accountId: string;
        name: string;
        externalIdentity: string;
        azureRegion: string;
        address: string;
        city: string;
        state: string;
        postalCode: string;
        country: string;
        timeZone?: number;
        latitude?: number;
        longitude?: number;
        rdpConnector: RdpConnectors;
        hosted: boolean;
        clusterId?: string;
    }
    interface ISiteLink {
        name: string;
        hostName: string;
        port: number;
        listenerCount: number;
    }
    interface ISiteServer {
        name: string;
        host: string;
    }
    interface IAzureWebsite {
        name: string;
        hybridConnectionRegistered: boolean;
    }
    interface ISiteLinkPrefetch {
        hybridConnection: ISiteLink;
        siteServers: Array<ISiteServer>;
        coreWebsites: Array<IAzureWebsite>;
    }
    interface IRdpEncodingLog {
        connectionId: string;
        path: string;
        progress: number;
        latestProgressUpdate: Date;
        requestedCancel: boolean;
        status: string;
        format: string;
    }
    class AmpRdpEncodingStatus {
        static NotStarted: string;
        static Encoding: string;
        static Encoded: string;
        static Canceled: string;
        static Failed: string;
    }
    module Services {
        class AmpSiteService {
            private _httpService;
            private $rsp;
            private _coreRoutePrefix;
            private _siteRoutePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService, $rsp: AmpSiteProxyService);
            listSites(): ng.IPromise<Array<ISite>>;
            getSite(id: string): ng.IPromise<ISite>;
            createSite(site: ISite): ng.IPromise<ISite>;
            updateSite(site: ISite): ng.IPromise<void>;
            deleteSite(id: string): ng.IPromise<void>;
            listSitesByAccount(accountId: string): ng.IPromise<Array<ISite>>;
            checkSiteRdpVideos(siteId: string, connectionIds: Array<string>): ng.IPromise<Array<string>>;
            getSiteRdpVideoUrl(id: string, connectionId: string): string;
            getSiteRdpEncodingLogs(siteId: string, connectionIds: Array<string>): ng.IPromise<Array<IRdpEncodingLog>>;
            getSiteRdpEncodingLog(siteId: string, connectionId: string): ng.IPromise<IRdpEncodingLog>;
            startSiteRdpEnconding(siteId: string, connectionId: string): ng.IPromise<void>;
            cancelSiteRdpEnconding(siteId: string, connectionId: string): ng.IPromise<void>;
            getSiteLink(siteId: string): ng.IPromise<ISiteLink>;
            getSiteLinkPrefetch(siteId: string): ng.IPromise<ISiteLinkPrefetch>;
            createSiteLink(siteId: string): ng.IPromise<ISiteLink>;
            deleteSiteLink(siteId: string): ng.IPromise<void>;
            getSiteLinkConnectionString(siteId: string): ng.IPromise<string>;
            getSiteIntegrationKey(siteId: string): ng.IPromise<string>;
            createSiteIntegrationKey(siteId: string): ng.IPromise<string>;
            deleteSiteIntegrationKey(siteId: string): ng.IPromise<void>;
            uploadSiteInstaller(siteId: string, packageName: string): ng.IPromise<any>;
            regenerateSiteInstallers(siteId: string): ng.IPromise<any>;
            createSiteInstaller(siteId: string, packageName: string): ng.IPromise<any>;
            installMonitoring(siteId: string): ng.IPromise<any>;
            installProductionMonitoring(siteId: string): ng.IPromise<any>;
            installMonitoringBundles(siteId: string, bundleIds: Array<string>): ng.IPromise<any>;
            installProductionMonitoringBundles(siteId: string, bundleIds: Array<string>): ng.IPromise<any>;
        }
    }
}
declare module AmpCoreApi {
    interface ISiteTarget {
        id?: string;
        name?: string;
        type?: string;
        externalIdentity?: string;
        endpoints?: Array<string>;
        properties?: {
            [indexer: string]: any;
        };
        node?: string;
        isNode?: boolean;
        lastModifiedDate?: string;
        tenant?: string;
    }
    module Services {
        class AmpSiteTargetService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            list(siteId: string): ng.IPromise<Array<ISiteTarget>>;
            store(siteId: string, target: ISiteTarget, id?: string): ng.IPromise<void>;
            storeMultiple(siteId: string, targets: Array<ISiteTarget>): ng.IPromise<void>;
            remove(siteId: string, id: string): ng.IPromise<void>;
            removeMultiple(siteId: string, ids: Array<string>): ng.IPromise<void>;
            get(siteId: string, id: string): ng.IPromise<ISiteTarget>;
            reallocate(siteId: string, node?: string): ng.IPromise<void>;
            private routeToId(id);
        }
    }
}
declare module AmpCoreApi {
    interface ISiteDeployment {
        probes: Array<ISiteProbe>;
        percolators: Array<ISitePercolator>;
        triggers: Array<ISiteTrigger>;
    }
    module Services {
        class AmpSiteDeploymentService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            getBundles(siteId: string): ng.IPromise<{
                [bundle: string]: string;
            }>;
            getProductionBundles(siteId: string): ng.IPromise<{
                [bundle: string]: string;
            }>;
        }
    }
}
declare module AmpCoreApi {
    interface ISiteTrigger extends ISiteIssuer {
        crontab?: string;
        issueScript?: string;
    }
    interface ISiteTriggerTestResponse {
        rawQueryResponse: string;
        results: Array<IResult>;
    }
    module Services {
        class AmpSiteTriggerService {
            private $q;
            private $rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor($rsp: AmpSiteProxyService);
            test(siteId: string, c: ISiteTrigger): ng.IPromise<Array<IResult>>;
            testWithRaw(siteId: string, c: ISiteTrigger): ng.IPromise<ISiteTriggerTestResponse>;
            private routeToId(id);
        }
    }
}
declare module AmpCoreApi {
    interface ISubscription extends IEntity {
        externalIdentity: string;
        mgmtCert: string;
        tenantId: string;
    }
    module Services {
        class AmpSubscriptionService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listSubscriptions(): ng.IPromise<Array<ISubscription>>;
            getSubscription(id: string): ng.IPromise<ISubscription>;
            createSubscription(subscription: ISubscription): ng.IPromise<ISubscription>;
            deleteSubscription(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface ITarget extends ITrackedEntityBase {
        name: string;
        siteId: string;
        type: string;
        externalIdentity: string;
        endpoints: Array<string>;
        properties: {
            [indexer: string]: any;
        };
        shouldBeMonitored: boolean;
        tenant: string;
        tenantDisplayName?: string;
        targetEndpoints: Array<ITargetEndpoint>;
    }
    interface ITargetSiteAccount {
        target: ITarget;
        account: IAccount;
        site: ISite;
    }
    interface ITargetEndpoint {
        uri: string;
        protocol: string;
        host: string;
        port: number;
        path: string;
        query: string;
        fragment: string;
    }
    class AmpTargetProtocol {
        static rdp: string;
        static powershell: string;
        static ssh: string;
        static http: string;
        static https: string;
        static monitoring: string;
    }
    module Services {
        class AmpTargetService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listTargets(siteId?: string, type?: string): ng.IPromise<Array<ITarget>>;
            getTarget(id: string): ng.IPromise<ITarget>;
            private fixupTargetEndpoints(target);
            getTargetSiteAccount(id: string): ng.IPromise<ITargetSiteAccount>;
            getTargetByExternalId(siteId: string, externalId: string): ng.IPromise<ITargetSiteAccount>;
            listTargetTypes(siteId?: string): ng.IPromise<Array<string>>;
            getTargetCapability(target: ITarget, protocol: string): boolean;
            parseUri(uri: string): ITargetEndpoint;
        }
    }
}
declare module AmpCoreApi {
    interface ITenant extends IEntity {
        name: string;
        externalIdentity: string;
    }
    module Services {
        class AmpTenantService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listTenants(): ng.IPromise<Array<ITenant>>;
            getTenant(id: string): ng.IPromise<ITenant>;
            createTenant(tenant: ITenant): ng.IPromise<ITenant>;
            updateTenant(tenant: ITenant): ng.IPromise<void>;
            deleteTenant(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface ITimeZone {
        id: number;
        name: string;
        offset: string;
    }
    module Services {
        class AmpTimeZoneService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listTimeZones(): ng.IPromise<Array<ITimeZone>>;
        }
    }
}
declare module AmpCoreApi {
    interface ITrigger extends IIssuer {
        crontab?: string;
        issueScript?: string;
    }
    module Services {
        class AmpTriggerService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listTriggers(): ng.IPromise<ITrigger[]>;
            getTrigger(id: string): ng.IPromise<ITrigger>;
            createTrigger(trigger: ITrigger): ng.IPromise<ITrigger>;
            updateTrigger(trigger: ITrigger, comment?: string): ng.IPromise<void>;
            deleteTrigger(id: string): ng.IPromise<void>;
            listTriggersByBundle(bundleId: string): ng.IPromise<ITrigger[]>;
        }
    }
}
declare module AmpCoreApi {
    interface ITypeBundleMap extends IEntity {
        type: string;
        bundleId: string;
        siteId: string;
    }
    module Services {
        class AmpTypeBundleMapService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listTypeBundleMaps(siteId?: string, type?: string): ng.IPromise<Array<ITypeBundleMap>>;
            getTypeBundleMap(id: string): ng.IPromise<ITypeBundleMap>;
            createTypeBundleMap(map: ITypeBundleMap): ng.IPromise<ITypeBundleMap>;
            deleteTypeBundleMap(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface IUserSetting extends IEntity {
        key: string;
        value: string;
    }
    interface IPersistenceLayer {
        setItem(key: string, value: string): ng.IPromise<void>;
        getItem(key: string): ng.IPromise<string>;
        clear(): ng.IPromise<void>;
        removeItem(key: string): ng.IPromise<void>;
    }
    module Services {
        class AmpUserSettingService implements IPersistenceLayer {
            private $q;
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor($q: ng.IQService, httpService: AmpHttpService);
            setItem(key: string, value: string): ng.IPromise<void>;
            getItem(key: string): ng.IPromise<string>;
            clear(): ng.IPromise<void>;
            removeItem(key: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    module Services {
        class AmpSiteRenderIssuesService {
            private _httpService;
            private _routePrefix;
            private _renderSuffix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            renderIssues(id: string, store: boolean, data: Array<IResult>): ng.IPromise<Array<IIssue>>;
            getRenderedIssues(id: string, peek: boolean): ng.IPromise<Array<IIssue>>;
        }
    }
}
declare module AmpCoreApi {
    enum EntityAuditAction {
        Deleted = 0,
        Modified = 1,
        Added = 2,
    }
    interface IEntityAuditRecord extends IEntity {
        entityId: string;
        tableName: string;
        action: EntityAuditAction;
        userIdentity: string;
        columnName: string;
        comment?: string;
        newValue: string;
        originalValue: string;
        timestamp: string;
    }
    module Services {
        class AmpEntityAuditLogService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listEntityAuditLogs(entityId: string, size?: number): ng.IPromise<Array<IEntityAuditRecord>>;
        }
    }
}
declare module AmpCoreApi {
    interface IVaultSecret extends IEntity {
        name: string;
        siteId: string;
        credentialId?: string;
        tenant?: string;
    }
    interface IVaultSecretNew {
        name: string;
        domain?: string;
        username: string;
        password: string;
        tenant?: string;
    }
    module Services {
        class AmpVaultService {
            private _httpService;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor(httpService: AmpHttpService);
            list(siteId: string): ng.IPromise<Array<IVaultSecret>>;
            create(siteId: string, c: IVaultSecretNew): ng.IPromise<IVaultSecretNew>;
            update(siteId: string, secretId: string, newSecret: string): ng.IPromise<string>;
            remove(siteId: string, secretId: string): ng.IPromise<void>;
            private _buildRoute(siteId);
        }
    }
}
declare module AmpCoreApi {
    interface ICoreCluster extends IEntity {
        name: string;
        azureRegion: string;
        uri: string;
    }
    interface ICoreNewCluster extends ICoreCluster {
        username: string;
        password: string;
    }
    module Services {
        class AmpCoreClusterService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listCoreClusters(): ng.IPromise<Array<ICoreCluster>>;
            getCoreCluster(id: string): ng.IPromise<ICoreCluster>;
            deleteCoreCluster(id: string): ng.IPromise<void>;
            createCoreCluster(coreCluster: ICoreNewCluster): ng.IPromise<ICoreCluster>;
        }
    }
}
declare module AmpCoreApi {
    class ListWithSelection<T extends Object> {
        private _items;
        private _selectedItem;
        private _indexField;
        private _itemsById;
        constructor(items: Array<T>, indexField?: string);
        private reindex();
        setItems(items: Array<T>): void;
        isSelected(item: T | string): boolean;
        selectItem(item: T | string): T;
        getItem(index: string): T;
        getIndices(): Array<string>;
        clear(): Array<T>;
        contains(item: T | string): boolean;
        addItem(item: T): void;
        removeItem(item: T | string): void;
        selectedItem: T;
        items: Array<T>;
        length: number;
    }
}
declare module AmpCoreApi {
    class Utils {
        static getBuildVersionFromScriptSrc(): string;
    }
}
declare module AmpCoreApi {
    var IID: string;
    var version: string;
}
declare module AmpCoreApi {
    interface ICoreSettings extends IEntity {
        validateReferenceTicket: boolean;
    }
    module Services {
        class AmpCoreSettingsService {
            private httpService;
            private routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            getCoreSettings(): ng.IPromise<ICoreSettings>;
            createCoreSettings(settings: ICoreSettings): ng.IPromise<ICoreSettings>;
            updateCoreSettings(settings: ICoreSettings): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface ICoreSgRole extends IEntity {
        id: string;
        role: string;
        coreSgId: string;
    }
    module Services {
        class AmpCoreSgRoleService {
            private _httpService;
            private _routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            listCoreSgRoles(): ng.IPromise<Array<ICoreSgRole>>;
            listCoreSgRolesByGroup(sgId: string): ng.IPromise<Array<ICoreSgRole>>;
            getCoreSgRole(id: string): ng.IPromise<ICoreSgRole>;
            createCoreSgRoles(coreSg: ICoreSgRole): ng.IPromise<ICoreSgRole>;
            deleteCoreSgRoles(id: string): ng.IPromise<void>;
        }
    }
}
declare module AmpCoreApi {
    interface IPackage {
        id: string;
        displayName: string;
        name: string;
        version: string;
    }
    module Services {
        class AmpPackageService {
            private httpService;
            private routePrefix;
            static IID: string;
            static $inject: Array<string>;
            constructor(httpService: AmpHttpService);
            getPackages(): ng.IPromise<Array<IPackage>>;
        }
    }
}
declare module AmpCoreApi {
    interface IClusterHealth {
        cluster_name: string;
        status: string;
        timed_out: boolean;
        number_of_nodes: number;
        number_of_data_nodes: number;
        active_primary_shards: number;
        active_shards: number;
        relocating_shards: number;
        initializing_shards: number;
        unassigned_shards: number;
        number_of_pending_tasks: number;
    }
    module Services {
        class AmpSiteElasticHealthService {
            private $q;
            private rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor(rsp: AmpSiteProxyService);
            getClusterState(siteId: string): ng.IPromise<any>;
            getClusterStateFiltered(siteId: string): ng.IPromise<any>;
            getClusterStats(siteId: string): ng.IPromise<any>;
            getClusterHealth(siteId: string): ng.IPromise<IClusterHealth>;
            getClusterNodes(siteId: string): ng.IPromise<any>;
            getClusterNodeStats(siteId: string): ng.IPromise<any>;
        }
    }
}
declare module AmpCoreApi {
    interface IHostSoftware {
        [host: string]: Array<ISoftware>;
    }
    interface ISoftware {
        name: string;
        version: string;
    }
    module Services {
        class AmpSiteSoftwareService {
            private $q;
            private rsp;
            private routePrefix;
            static IID: string;
            static $inject: string[];
            constructor(rsp: AmpSiteProxyService);
            getAllSoftware(siteId: string): ng.IPromise<IHostSoftware>;
        }
    }
}
